@@ -1,7 +1,7 @@
 class ParameterBase:
 
     def __init__(self, *args, **kwargs):
-        return 
+        pass
 
     def as_kwargs(self):
         return self.__dict__
